#

##

##

##

    	external reverse proxy

    	objectives

    		[ ] load balance cloud flare DNS between
    			two "front_nodes" based on location.

    		[ ] DNS cache?

    			steps:
    				[ ] connect to veganmodule.com

    						regions:
    							address_1
    							address_2
    							address_3

    					[ ] DNS router says go to address_1

    						[ ] afterwards, unless DNS cache is cleared,
    							the requests go to "address_1"

    	cloudflare

    	relevant
    		forward proxy: